@@ -92,18 +92,20 @@ class Act():
         nap = 1
         starttime = time.time()
         elapsed = 0
-        while elapsed < timeout:
+        valid = False
+        while not valid and elapsed < timeout:
             try:
                 fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
                 new_ip, new_port = fullport.split(':')
                 if new_port <> start_port:
                     self.uwsgi_ip = new_ip
                     self.uwsgi_port = new_port
-                    break
+                    valid = True
             except:
                 pass
-            time.sleep(nap)
-            elapsed = time.time() - starttime
+            if not valid:
+                time.sleep(nap)
+                elapsed = time.time() - starttime
         return
 
 
